.. _spkg__cibuildwheel_local_windows:

_cibuildwheel_local_windows: Non-Python dependencies of packages for which we build platform wheels for Windows
===============================================================================================================


Type
----

optional


Dependencies
------------

- :ref:`spkg_boost_cropped`
- :ref:`spkg_cddlib`
- :ref:`spkg_cliquer`
- :ref:`spkg_cmr`
- :ref:`spkg_glpk`
- :ref:`spkg_gmp`
- :ref:`spkg_graphs`
- :ref:`spkg_gsl`
- :ref:`spkg_highs`
- :ref:`spkg_libgd`
- :ref:`spkg_libhomfly`
- :ref:`spkg_m4ri`
- :ref:`spkg_m4rie`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfr`
- :ref:`spkg_planarity`
- :ref:`spkg_rw`
- :ref:`spkg_symmetrica`


Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i _cibuildwheel_local_windows


